@@ -10,14 +10,17 @@ class TestCliAdapter(unittest.TestCase):
     def _make_project(self):
         td = tempfile.TemporaryDirectory()
         base = Path(td.name)
-        init_project("demo_algo", str(base), "D01", "1.0.0", "demo")
-        img = base / "test.bin"
-        with open(img, "wb") as f:
+        init_project("demo_algo", str(base), "1.0.0", "demo")
+        cur = base / "cur.bin"
+        guide = base / "guide.bin"
+        with open(cur, "wb") as f:
             f.write(b"\x00\x01demo")
-        return td, str(base), str(img)
+        with open(guide, "wb") as f:
+            f.write(b"\x00\x01demo2")
+        return td, str(base), str(cur), str(guide)
 
     def test_validate_full(self):
-        td, project, image = self._make_project()
+        td, project, cur, guide = self._make_project()
         try:
             report = validate_adapter(project, None)
             self.assertIn(report["summary"]["status"], {"PASS", "FAIL"})
@@ -26,10 +29,9 @@ class TestCliAdapter(unittest.TestCase):
             td.cleanup()
 
     def test_run_adapter(self):
-        td, project, image = self._make_project()
+        td, project, cur, guide = self._make_project()
         try:
-            res = run_adapter(project, "D01", image, json.dumps({"threshold": 0.8}), 1, None)
-            self.assertIsInstance(res.get("pre_execute"), dict)
+            res = run_adapter(project, cur, guide, 1, "demo", [], None)
             self.assertIsInstance(res.get("execute"), dict)
         finally:
             td.cleanup()
